@@ -5,9 +5,10 @@ knitr::opts_chunk$set(
   comment = "#>",
   eval = have_packages  # https://r-pkgs.org/vignettes.html#sec-vignettes-eval-option
 )
-# use devtools::build_rmd("vignettes/comparison.Rmd") to test build
-# library(rmarkdown); setwd( R'(C:\Users\James.Thorson\Desktop\Git\phylosem\vignettes)' )
-# use render( "demonstration.Rmd", pdf_document()) to build PDF, and perhaps tinytex::latexmk() to install dependencies
+# Test build:
+#  devtools::build_rmd("vignettes/comparison.Rmd")
+# Render example
+#  library(rmarkdown); setwd( R'(C:\Users\James.Thorson\Desktop\Git\phylosem\vignettes)' ); render( "demonstration.Rmd", pdf_document())
 
 ## ----setup, echo=TRUE---------------------------------------------------------
 library(phylosem)
@@ -44,16 +45,31 @@ knitr::kable(c("minimum_eigenvalue"=min(eigen(psem$opt$SD$jointPrecision)$values
              "maximum_eigenvalue"=max(eigen(psem$opt$SD$jointPrecision)$values)), digits=3)
 knitr::kable(Rsub, digits=3)
 
-## ----eval=have_packages, echo=TRUE, message=FALSE, fig.width=4, fig.height=4----
+## ----eval=have_packages, echo=TRUE, message=FALSE, fig.width=6, fig.height=4----
 library(ggplot2)
 # Compile estimates and SEs
 pdat = data.frame( "Estimate" = psem$opt$SD$par.fixed[c('lnalpha','logitlambda','lnkappa')],
               "StdErr" = sqrt(diag(V)[c('lnalpha','logitlambda','lnkappa')]) )
 pdat = cbind( pdat, "Param" = rownames(pdat))
 
-ggplot(pdat, aes( x=Param, y = Estimate, ymin = Estimate - 1.96*StdErr, ymax = Estimate + 1.96*StdErr)) +
+#
+pdat$lower = pdat$Estimate - 1.96*pdat$StdErr
+pdat$upper = pdat$Estimate + 1.96*pdat$StdErr
+pdat$type = "estimated"
+
+# Transform from log / logit-space to natural space
+pdat2 = pdat
+pdat2$Param = c("alpha", "lambda", "kappa")
+pdat2['lnalpha',c("Estimate","lower","upper")] = exp(pdat2['lnalpha',c("Estimate","lower","upper")])
+pdat2['lnkappa',c("Estimate","lower","upper")] = exp(pdat2['lnkappa',c("Estimate","lower","upper")])
+pdat2['logitlambda',c("Estimate","lower","upper")] = plogis(as.numeric(pdat2['logitlambda',c("Estimate","lower","upper")]))
+pdat2$type = "derived"
+
+# Plot
+ggplot( rbind(pdat,pdat2), aes( x=Param, y = Estimate, ymin = lower, ymax = upper)) +
   geom_pointrange(position = position_dodge(width = 0.6)) +
-  theme_classic()
+  theme_classic() +
+  facet_grid( rows=vars(type), scales="free" )
 
 ## ----eval=have_packages, echo=TRUE, message=FALSE, fig.width=6, fig.height=6, out.width = "75%"----
 # Settings
